@@ -64,7 +64,6 @@ class IdealColumn:
         
         y_feed_norm = np.array(np.array(y_feed)/ np.sum(y_feed))
         
-        print(y_feed_norm)
         for ii in range(len(y_feed_norm)):
             if y_feed_norm[ii] < 0.0001:
                 y_feed_norm[ii]  = 0.0001
@@ -104,8 +103,8 @@ class IdealColumn:
             return x_new
         x_guess_all = x2x(y_feed)
         x_guess = x_guess_all[:-1]
-        print('x_guess is:')
-        print(x_guess)
+        #print('x_guess is:')
+        #print(x_guess)
         def err_x2x(x_gu):
             Penalty = 0
             for xx, ii in zip(x_gu, range(len(x_gu))):
@@ -123,10 +122,10 @@ class IdealColumn:
                 Penalty = Penalty + 1000*(x_last - 1)**2
                 x_last = 1 - 1E-6
             x_all = np.append(np.array(x_gu), x_last)
-            print(x_all)
+            #print(x_all)
             x_recal = x2x(x_all)
             err_x = np.sum((x_all - x_recal)**2) + Penalty
-            print(Penalty)
+            #print(Penalty)
             return err_x
 
         optres = minimize(err_x2x, x_guess, method = 'Nelder-mead')
@@ -146,8 +145,8 @@ class IdealColumn:
 
         x_sol = optres.x
 
-        print('Funciton value of optimizaiton is ')
-        print(optres.fun)
+        #print('Funciton value of optimizaiton is ')
+        #print(optres.fun)
         x_last_sol = 1- np.sum(x_sol)
         x_purity = np.append(x_sol, x_last_sol)
         self.x_ideal = x_purity
